@@ -1,6 +1,5 @@
 #include "battery.h"
 #include "common/io/io.h"
-#include "detection/temps/temps_linux.h"
 #include "util/stringUtils.h"
 
 #include <dirent.h>
@@ -33,7 +32,7 @@ static void parseBattery(FFstrbuf* dir, const char* id, FFBatteryOptions* option
 
     //capacity must exist and be not empty
     ffStrbufAppendS(dir, "/capacity");
-    bool available = ffReadFileBuffer(dir->chars, &tmpBuffer);
+    bool available = ffReadFileBuffer(dir->chars, &tmpBuffer); // This is expensive in my laptop
     ffStrbufSubstrBefore(dir, dirLength);
 
     if (!available)
@@ -170,8 +169,5 @@ const char* ffDetectBattery(FFBatteryOptions* options, FFlist* results)
         ffStrbufSubstrBefore(&baseDir, baseDirLength);
     }
 
-    if(results->length == 0)
-        return "\"/sys/class/power_supply/\" doesn't contain any battery folder";
-
     return NULL;
 }
