@@ -1,5 +1,4 @@
 #include "cpu.h"
-#include "detection/temps/temps_windows.h"
 #include "util/windows/registry.h"
 #include "util/windows/nt.h"
 #include "util/mallocHelper.h"
@@ -54,31 +53,6 @@ typedef struct FFSmbiosProcessorInfo
 static_assert(offsetof(FFSmbiosProcessorInfo, ThreadEnabled) == 0x30,
     "FFSmbiosProcessorInfo: Wrong struct alignment");
 
-#if defined(__x86_64__) || defined(__i386__)
-
-#include <cpuid.h>
-
-inline static const char* detectSpeedByCpuid(FFCPUResult* cpu)
-{
-    uint32_t base = 0, max = 0, bus = 0, unused = 0;
-    if (!__get_cpuid(0x16, &base, &max, &bus, &unused))
-        return "Unsupported instruction";
-
-    // cpuid returns 0 MHz when hyper-v is enabled
-    if (base) cpu->frequencyBase = base / 1000.0;
-    if (max) cpu->frequencyMax = max / 1000.0;
-    return NULL;
-}
-
-#else
-
-inline static const char* detectSpeedByCpuid(FF_MAYBE_UNUSED FFCPUResult* cpu)
-{
-    return "Unsupported platform";
-}
-
-#endif
-
 static const char* detectMaxSpeedBySmbios(FFCPUResult* cpu)
 {
     const FFSmbiosHeaderTable* smbiosTable = ffGetSmbiosHeaderTable();
@@ -97,7 +71,7 @@ static const char* detectMaxSpeedBySmbios(FFCPUResult* cpu)
             return "No active CPU is found in SMBIOS data";
     }
 
-    double speed = data->MaxSpeed / 1000.0;
+    uint32_t speed = data->MaxSpeed;
     // Sometimes SMBIOS reports invalid value. We assume that max speed is small than 2x of base
     if (speed < cpu->frequencyBase || speed > cpu->frequencyBase * 2)
         return "Possible invalid CPU max speed in SMBIOS data. See #800";
@@ -126,9 +100,9 @@ static const char* detectNCores(FFCPUResult* cpu)
         ptr = (SYSTEM_LOGICAL_PROCESSOR_INFORMATION_EX*)(((uint8_t*)ptr) + ptr->Size)
     )
     {
-        if(ptr->Relationship == RelationProcessorCore)
+        if (ptr->Relationship == RelationProcessorCore)
             ++cpu->coresPhysical;
-        else if(ptr->Relationship == RelationGroup)
+        else if (ptr->Relationship == RelationGroup)
         {
             for (uint32_t index = 0; index < ptr->Group.ActiveGroupCount; ++index)
             {
@@ -157,6 +131,10 @@ static const char* detectByRegistry(FFCPUResult* cpu)
             cpu->coresOnline = cpu->coresPhysical = cpu->coresLogical = (uint16_t) cores;
     }
 
+    uint32_t mhz;
+    if(ffRegReadUint(hKey, L"~MHz", &mhz, NULL))
+        cpu->frequencyBase = mhz;
+
     return NULL;
 }
 
@@ -176,11 +154,13 @@ static const char* detectCoreTypes(FFCPUResult* cpu)
         ++cpu->coreTypes[ifreq].count;
     }
 
-    if (cpu->frequencyBase != cpu->frequencyBase)
-        cpu->frequencyBase = pinfo->MaxMhz / 1000.0;
+    if (cpu->frequencyBase == 0)
+        cpu->frequencyBase = pinfo->MaxMhz;
     return NULL;
 }
 
+const char* detectThermalTemp(double* current, double* critical);
+
 const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
 {
     detectNCores(cpu);
@@ -189,14 +169,14 @@ const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
     if (error)
         return error;
 
-    detectSpeedByCpuid(cpu);
-    detectCoreTypes(cpu);
+    ffCPUDetectSpeedByCpuid(cpu);
+    if (options->showPeCoreCount) detectCoreTypes(cpu);
 
-    if (cpu->frequencyMax != cpu->frequencyMax)
+    if (cpu->frequencyMax == 0)
         detectMaxSpeedBySmbios(cpu);
 
     if(options->temp)
-        ffDetectSmbiosTemp(&cpu->temperature, NULL);
+        detectThermalTemp(&cpu->temperature, NULL);
 
     return NULL;
 }
